@@ -1,9 +1,9 @@
-use crate::data::{get_version_specific_file, BLOCKS_FILE};
+use crate::data::{get_version_specific_file, BLOCKS_FILE, BLOCK_COLLISION_SHAPES_FILE};
 use crate::models::block::Block;
+use crate::models::block_collision_shapes::BlockCollisionShapes;
 use crate::models::version::Version;
 use crate::DataResult;
 use std::collections::HashMap;
-use std::iter::FromIterator;
 use std::sync::Arc;
 
 pub struct Blocks {
@@ -26,7 +26,7 @@ impl Blocks {
     /// Returns the blocks indexed by ID
     pub fn blocks(&self) -> DataResult<HashMap<u32, Block>> {
         let blocks = self.blocks_array()?;
-        let blocks_map = HashMap::from_iter(blocks.into_iter().map(|b| (b.id, b)));
+        let blocks_map = blocks.into_iter().map(|b| (b.id, b)).collect();
 
         Ok(blocks_map)
     }
@@ -34,8 +34,16 @@ impl Blocks {
     /// Returns the blocks indexed by name
     pub fn blocks_by_name(&self) -> DataResult<HashMap<String, Block>> {
         let blocks = self.blocks_array()?;
-        let blocks_map = HashMap::from_iter(blocks.into_iter().map(|b| (b.name.clone(), b)));
+        let blocks_map = blocks.into_iter().map(|b| (b.name.clone(), b)).collect();
 
         Ok(blocks_map)
     }
+
+    /// Returns the block collision shapes object
+    pub fn block_collision_shapes(&self) -> DataResult<BlockCollisionShapes> {
+        let content = get_version_specific_file(&self.version, BLOCK_COLLISION_SHAPES_FILE)?;
+        let collision_shapes = serde_json::from_str(&content)?;
+
+        Ok(collision_shapes)
+    }
 }
